import request, { postBlob, getBlob, handleImport } from '@/utils/request'

// 获取师傅列表
export function memberListPageV2(data) {
  return request({
    url: `/member/list/page2?moduleId=${data.moduleId}`,
    method: 'post',
    data
  })
}

export function memberPageExport(data, name) {
  return postBlob({
    url: '/member/pageExport',
    data,
    name
  })
}


// 审核
export function memberAudit(params) {
  return request({
    url: '/member/worker/examine',
    method: 'post',
    params
  })
}

// 获取详情
export function getMemberDetail(params) {
  return request({
    url: '/member/worker/examine/detail',
    method: 'get',
    params
  })
}

// 设置取消分销员
export function memberInner(data) {
  return request({
    url: '/member/batch/type',
    method: 'post',
    data
  })
}


export function memberSlaveBind(params) {
  return request({
    url: '/member/slave/bind',
    method: 'post',
    params
  })
}

export function update(params) {
  return request({
    url: '/member/worker/update',
    method: 'post',
    params
  })
}